---
title: "Pointer in Go"
date: 2019-09-10
draft: false
tags: ["programmieren","golang","go","datenstrukturen","zeiger","pointer"]
categories: ["Archive"]
---
Ein Pointer in Go, oder auch Zeiger verweist auf die Speicheradresse an der ein Wert gesichert ist. Um die Speicheradresse für eine Variable auszugeben verwendet man das & Zeichen:

```go
func main() {
	x := 10
	fmt.Println(x)
	fmt.Println(&x)
	
	fmt.Printf("%T\n", x)
	fmt.Printf("%T\n", &x)
}
```

Gibt man Typ der Speicheradresse ausgeben, so ist er \int. Da \ ist der Operator für einen Pointer, dass heißt, die Speicheradresse ist ein Pointer zu einem int. Mit anderen Worten zeigt der Pointer zeigt auf eine Speicheradresse an der ein Wert vom Typ int gespeichert ist.

Man muss hier klarstellen, dass ein Pointer zu einem int ein eigener Typ ist und nicht dem Typ int gleichzusetzen ist.

```go
func main() {
	x := 10
	
	y := &x
	fmt.Println(y)
	fmt.Println(y)
}
```

In Zeile 6 wird der Operator \ verwendet. Dieser dereferenziert die in y gespeicherte Speicheradressem d.h. er gibt den dort gespeicherten Wert aus. 

```go
func main() {
	x := 10
	
	y := &x
	y = 88
	fmt.Println(x)
}
```

Hier wird x = 88 gesetzt. Das liegt daran, dass die Variable y die Speicheradresse x enthält. Durch die Verwendung \y = 88 passiert wieder eine Dereferenzierung, d.h. man sagt dem Programm im Grunde "Setze den Wert, der sich an der in y gespeicherten Adresse befindet gleich 88".

## Wie Pointer benutzt werden

Pointer sind dann besonders nützlich, wenn man große Datemengen übergeben möchte. Es ist wesentlich effizienter auf die Adresse zu verweisen an der die Daten gespeichert sind statt die Daten an sich zu übergeben.

Der zweite Anwendungsfall ist der, dass man manchmal Werte an einer Adresse ändern möchte. 

```go
func main() {
	var x int = 5
	fmt.Println("Adresse x", &x)
	zahlen(&x)
}

func zahlen(x int) {
	fmt.Println("x vorher ",x)
	fmt.Println("Adresse x", &x)
	x = 48
	fmt.Println("x nachher ",x)
	fmt.Println("Adresse x", &x)
}
```

Die Funktion zahlen() konsumiert einen Pointer vom Typ int, d.h. wir übergeben in Zeile 3 die Speicheradresse x indem wir &x übergeben. Die Speicheradresse bleibt im oberen Beispiel immer die gleiche, während wir den Wert an der Adresse ändern.

Die Funktion zahlen() hat keinen Zugriff auf. Selbst wenn x direkt an sie übergeben würde wäre es nicht möglich x zu ändern, da bei Übergabe an die Funktion eine Kopie x erstellt wird.

## Methodensatz

Eine Methodensatz sind die Methoden, die einem bestimmten Datentyp zugerordnet sind. Ein Methodensatz bestimmt die Schnittstellen (Interfaces), die der jeweilige Typ implementiert.

Bei den Methodensätzen gibt es einen wichtigen Unterschied beim Empfänger Argumenten:

Ein Receiver, der nicht als Pointer definiert ist funktioniert mit mit Pointern und auch mit nicht-Pointern.

Ein Receiver, der als Pointer definiert ist funktioniert nur mit Pointern.

```go
package main

import (
	"fmt"
	"math"
)

type kreis struct {
	radius float64
}

type form interface {
	flaeche() float64
}

func (k kreis) flaeche() float64 {
	return math.Pi  k.radius  k.radius
}

func info(f form) {
	fmt.Println("Fläche", f.flaeche())
}

func main() {
	k := kreis{5}
	info(&k)  //Pointer Übergabe
	info(k)   //Nicht-Pointer Übergabe
}

```

Die Aufrufe in Zeile 26 und 27 führen beide zum selben Ergebnis. Würde man die Methode flaeche() anders definieren würde der Aufruf in Zeile 27 einen Fehler verursachen:

```go
...
func (k kreis) flaeche() float64 {
	return math.Pi  k.radius  k.radius
}
...

func main() {
	k := kreis{5}
	info(&k)  //Pointer Übergabe
	info(k)   //Nicht-Pointer Übergabe // FEHLER
}
```

Der Grund warum info(k) fehlschlägt ist, dass die Funktion konkret nach einem Pointer vom Typ kreis verlangt. Da wie oben schon beschrieben ein Pointer vom Typ kreis ein eigenständiger Typ ist und nicht das gleiche wie der Typ kreis muss hier auch ein Pointer übergeben werden.



